@@ -114,50 +114,6 @@ void do_warn(SV* h, int rc, char* what) {
  *
  **************************************************************************/
 
-static int Login(SV* dbh, imp_dbh_t* imp_dbh, char* dbname, char* user,
-		 char* password) {
-    char* copy = NULL;
-    char* host = NULL;
-    char* ptr;
-
-    /*
-     *  dbname may be "db:host" or "db;host"
-     */
-    if ((ptr = strchr(dbname, ':'))  ||  (ptr = strchr(dbname, ';'))) {
-        int len = ptr-dbname;
-	copy = (char*) malloc(strlen(dbname)+1);
-	strcpy(copy, dbname);
-	dbname = copy;
-	host = dbname + len;
-	*host++ = '\0';
-    }
-
-    /*
-     *  Try to connect
-     */
-#xtract Mysql
-    imp_dbh->svsock = &imp_dbh->mysql;
-    if (!dbd_db_connect(imp_dbh->svsock, host, user, password)) {
-#xtract Msql
-    if (!dbd_db_connect(&imp_dbh->svsock, host, user, password)) {
-#endxtract
-	if (copy) free(copy);
-	return FALSE;
-    }
-
-    /*
-     *  Connected, now try to login
-     */
-    if (MySelectDb(imp_dbh->svsock, dbname)) {
-        if (copy) free(copy);
-	MyClose(imp_dbh->svsock);
-	return FALSE;
-    }
-
-    if (copy) free(copy);
-    return TRUE;
-}
-
 int dbd_db_login(SV* dbh, imp_dbh_t* imp_dbh, char* dbname, char* user,
 		 char* password) {
     if (dbis->debug >= 2)
@@ -166,7 +122,12 @@ int dbd_db_login(SV* dbh, imp_dbh_t* imp_dbh, char* dbname, char* user,
 	       user ? user : "NULL",
 	       password ? password : "NULL");
 
-    if (!Login(dbh, imp_dbh, dbname, user, password)) {
+#xtract Msql
+    if (!MyLogin(&imp_dbh->svsock, dbname, user, password)) {
+#xtract Mysql
+    imp_dbh->svsock = &imp_dbh->mysql;
+    if (!MyLogin(imp_dbh->svsock, dbname, user, password)) {
+#endxtract
 	DO_ERROR(dbh, MyErrno(imp_dbh->svsock, JW_ERR_CONNECT),
 		 imp_dbh->svsock);
 	return FALSE;
@@ -732,6 +693,7 @@ AV* dbd_st_fetch(SV* sth, imp_sth_t* imp_sth) {
 	    DO_ERROR(sth, JW_ERR_FETCH_ROW, imp_dbh->svsock);
 	}
 #endxtract
+        dbd_st_finish(sth, imp_sth);
 	return Nullav;
     }
 #xtract Mysql
@@ -925,7 +887,7 @@ int dbd_st_STORE_attrib(SV* sth, imp_sth_t* imp_sth, SV* keysv, SV* valuesv) {
 #endif
 
 SV* dbd_st_FETCH_internal(SV* sth, int what, result_t res, int cacheit) {
-    imp_sth_t* imp_sth;
+    D_imp_sth(sth);
     AV *av = Nullav;
     field_t curField;
 
@@ -938,8 +900,7 @@ SV* dbd_st_FETCH_internal(SV* sth, int what, result_t res, int cacheit) {
     /*
      *  Return cached value, if possible
      */
-    } else if (cacheit  &&
-	       (imp_sth = (imp_sth_t*) DBIh_COM(sth))->av_attr[what]) {
+    } else if (cacheit  &&  imp_sth->av_attr[what]) {
 	av = imp_sth->av_attr[what];
 
     /*
@@ -1037,6 +998,8 @@ SV* dbd_st_FETCH_internal(SV* sth, int what, result_t res, int cacheit) {
 #endxtract
 		    };
 		    int i, found = FALSE;
+
+		    sv = &sv_undef;
 		    for (i = 0;  i < sizeof(types) / sizeof(struct db_types);
 			 i++) {
 			if (curField->type == types[i].id) {
@@ -1380,8 +1343,13 @@ int MysqlReconnect(SV* h) {
         return FALSE;
     }
     password = *svp;
-    return Login(h, imp_dbh, SvPV(dbname, na), SvPV(user, na),
-		 SvPV(password, na));
+    if (!MyLogin(imp_dbh->svsock, SvPV(dbname,na), SvPV(user,na),
+		 SvPV(password,na))) {
+	DO_ERROR(h, MyErrno(imp_dbh->svsock, JW_ERR_CONNECT),
+		 imp_dbh->svsock);
+	return FALSE;
+    }
+    return TRUE;
 }
 
 #endxtract
