@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.01_02';
+$VERSION = '2.01_03';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -302,20 +302,19 @@ of the I<Msql-Mysql-modules> package.
 
     use DBI;
 
-    $dbh = DBI->connect("DBI:mSQL:$database", undef, undef);
-    $dbh = DBI->connect("DBI:mSQL:$database:$hostname", undef, undef);
-    $dbh = DBI->connect("DBI:mSQL:$database:$hostname:$port",
-			undef, undef);
+    $dsn = "DBI:mSQL:$database";
+    $dsn = "DBI:mSQL:database=$database;host=$hostname";
+    $dsn = "DBI:mSQL:database=$database;host=$hostname;port=$port";
+
+    $dbh = DBI->connect($dsn, undef, undef);
 
         or
 
-    use DBI;
+    $dsn = "DBI:mysql:$database";
+    $dsn = "DBI:mysql:database=$database;host=$hostname";
+    $dsn = "DBI:mysql:database=$database;host=$hostname;port=$port";
 
-    $dbh = DBI->connect("DBI:mysql:$database", $user, $password);
-    $dbh = DBI->connect("DBI:mysql:$database:$hostname",
-			$user, $password);
-    $dbh = DBI->connect("DBI:mysql:$database:$hostname:$port",
-			$user, $password);
+    $dbh = DBI->connect($dsn, $user, $password);
 
 A C<database> must always be specified.
 
@@ -807,6 +806,35 @@ such as books, magazine articles or CD-ROMs should be made to
 Alligator Descartes <I<descarte@hermetica.com>>.
 
 
+=head1 MAILING LIST SUPPORT
+
+This module is maintained and supported on a mailing list,
+
+    msql-mysql-modules@tcx.se
+
+To subscribe to this list, send a mail with the words
+
+    subscribe msql-mysql-modules
+
+or
+
+    subscribe msql-mysql-modules-digest
+
+in the first line of the body to mdomo@tcx.se. A mailing list archive is
+in preparation.
+
+Additionally you might try the dbi-user mailing list for questions about
+DBI and its modules in general. Subscribe via
+
+    http://www.fugue.com/dbi
+
+Mailing list archives are at
+
+     http://www.rosat.mpe-garching.mpg.de/mailing-lists/PerlDB-Interest/
+     http://outside.organic.com/mail-archives/dbi-users/
+     http://www.coe.missouri.edu/~faq/lists/dbi.html
+
+
 =head1 ADDITIONAL DBI INFORMATION
 
 Additional information on the DBI project can be found on the World
